<?php
if(!defined('WIKI_PAPERS_PLUGIN')) die();
require_once(WIKI_PAPERS_PLUGIN.'functions.php');

function getNumberOfPublications($bibliography, $options, $url, $baseurl, $author, $year, $to_year=null){
	switch ($bibliography){
		case "DBLP":
			return getDBLPPublications($options, $url, $baseurl, $author, $year, $to_year);
			break;
		case "BPP":
			return getBPPPublications($options, $url, $baseurl, $author, $year, $to_year);
		//case "CiteSeerX":
		//	return getCiteSeerXPublications($options, $url, $baseurl, $author, $year, $to_year);
		default:
			return "Error: Unknown bibliography: \"$bibliography\".";
	}
}

function get_page_by_curl($url){
	if(function_exists('set_time_limit')) {
		set_time_limit(30);
	}
	try {
		$safe = (ini_get('safe_mode') || ini_get('open_basedir'));
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_MAXREDIRS, 1);
		curl_setopt($ch, CURLOPT_HEADER, true); 
		if (!$safe){
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
		}
		$data = curl_exec($ch);
		list($header, $site) = explode("\n\n", $data, 2);
		
		if ($safe){
			$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			if ($http_code == 301 || $http_code == 302) {
				$matches = array();
				preg_match('/Location:(.*?)\n/', $header, $matches);
				$url = @parse_url(trim(array_pop($matches)));
				if (isset($url) && $url !== false && $url != ""){// return $site;
					//$last_url = parse_url(curl_getinfo($ch, CURLINFO_EFFECTIVE_URL));
					$new_url = $url['scheme'] . '://' . $url['host'] . $url['path'] . ($url['query']?'?'.$url['query']:'');
					curl_setopt($ch, CURLOPT_URL, $new_url);
					curl_setopt($ch, CURLOPT_HEADER, false); 
					$data = curl_exec($ch);
				}
			}
		}
		curl_close($ch);
		return $data;
	} catch (Exception $e) {
		return $null;
	}
}

function getDBLPPublications($options, $url, $baseurl, $author, $year, $to_year){
	$autenc = urlencode($author);
	$urlchanged = false;
	if ($url == ""){
		if ($baseurl == ""){
			$url = "http://dblp.uni-trier.de/search/author?author=$autenc";
			$urlchanged = true;
		} else {
			$url = $baseurl;
		}
	}
	
	if (isset($to_year)) $years = range($year, $to_year);
	else $years = array($year);
	
	$site = get_page_by_curl($url);
	if (!isset($site) || $site == "") return array("cURL Error", $url);
	
	if (get_string_between($site, "<title>", "</title>") == "Author Search"){
		if ($urlchanged){
			if (strpos($site, "<ul>")){
				return array("Error: Specify author more precisely.", $url);
			}
			return array("Error: There is no author: \"$author\".", $url);
		}
		return array("Error: Incorrect URL.", $url);
	}
	
	$table = make_table($site, "<table", "</table>");
	if (!isset($table[1])) return array("Error: Incorrect URL.", $url);
	$table = make_table($table[1], "<tr", "</tr>");
		
	$add_position = false;
	$counter = 0;
	$tmpl=$tmpr="";
	foreach ($table as $row_n => $row){
		
		if (contains_str($row, "<th")){
			$headers = make_table($row, "<th", "</th>");
			$y = 0;
			//$counter += $h;
			foreach ($headers as $hn => $h) if (is_numeric($h = decompose_string_between($h, ">", "", $tmpl, $tmpr))) {$y = $h; break;}
			$add_position = in_array($y, $years);
		} else if ($add_position){
			$counter++;
		}
	}
	return array($counter, $url);
}

function getBPPPublications($options, $url, $baseurl, $author, $year, $to_year){
	$urlchanged = false;
	if (!isset($year)) $year = 0;
	if ($url == "" || isset($to_year)){
		$urlchanged = true;
		$autenc = urlencode($author);
		$yenc = urlencode($year);
		$toyenc = urlencode((isset($to_year)) ? $to_year : $year);
		//$yarSuffix = (isset($to_year)) ? "&odR=$yenc&doR=$toyenc" : "&R=$yenc";
		$ifSuffix = ($options == 'IF') ? "&fsImFa=on" : "";
		if ($url == ""){
			if ($baseurl == ""){
				$url = "http://www.bpp.agh.edu.pl/bpp-show.phtml?s=c&fsA=$autenc";
			} else {
				$url = $baseurl;
			}
			$url .= $ifSuffix;
		}
	}
	$url_to_show = $url;
	if ($urlchanged) $url_to_show .= "&R=" . ((isset($to_year)) ? "0" : "$year");
	$ur2 = $url;
	if (!isset($to_year)) $to_year = $year;
	$result = 0;
	for	($yearN = $year; $yearN <= $to_year; $yearN++){
		if ($urlchanged) $url = $ur2. "&R=" . urlencode($yearN);
		$site = get_page_by_curl($url);
		
		if (!isset($site)) return array("cURL Error at this location", $url);
		if (substr_count($site, "<title>Bibliographic list of staff publications") == 0) return array("Bad URL", $url);
		
		$ptl = '<ol id="ol-opis">';
		$ptr = "</ol>";
		
		if (!contains_str($site, $ptl) && !contains_str($site, '<div id="brak">')){
			if ($urlchanged) return array("Error: There is no author: \"$author\".", $url);
			if ($baseurl) return array("Error: Bad base URL.", $url);
			return array("Error: Bad URL.", $url);
		}
		
	//	$site1 = $site;
		$site = " " . get_string_between($site, $ptl, $ptr);
		
		switch ($options){
		case "MNiSW":
			$ptl = "punktacja MNiSW: <b>";
			$ptr = "</b>";
			
			$sum = 0;
			$str = $site;
			while (true){
				$pts = cut_string_between($str, $ptl, $ptr);
				if ($pts == "" || $pts === null) break;
				$sum += $pts;
			}
			$result += $sum;
			break;
		case "LF":
			$ptl = '<div class="iimfa">';
			$ptr = "</div>";
			$pattern = preg_quote("<b>LF</b>", "/");
			$result += search_in($site, $ptl, $ptr, $pattern);
			break;
		case "IF":
			$ptl = '<div class="iimfa">';
			$ptr = "</div>";
			$pattern = "Impact Factor";
			$result += search_in($site, $ptl, $ptr, $pattern);
			break;
		case "LNCS":
			$ptl = '<li>';
			$ptr = "</li>";
			$pattern = "LNCS";
			$result += search_in($site, $ptl, $ptr, $pattern);
			break;
		default:
			$ptl = '<li>';
			$ptr = "</li>";
			$pattern = "";
			$result += search_in($site, $ptl, $ptr, $pattern);
			break;
		}
	}
	return array($result, $url_to_show);
}

function getCiteSeerXPublications($options, $url, $baseurl, $author, $year){
	return array("CiteSeerX Not written", $url);
}
?>